==> hermes-5.9.0.11.tar.gz: hermes-5.9.0.11/app/controllers/hermes/api/dmo/lessors_controller.rb <==
# frozen_string_literal: true
require 'json'
module Hermes
  module Api
    module Dmo
      # checker Api::Dmo::HermesController avant d'ajouter des methodes
      class LessorsController < Hermes::Api::Dmo::ApplicationController
        set_instance_for :objectives

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $eq
          $regex
          $all
        ]

        ACCEPTABLE_PARAMS = %w[
          ids
          als_id
          created_at
          updated_at
          title
          siret
          siren
          is_root
          root_id
          parent_id
          id_rex
          id_cristal
          api_id
          rpls_id
          affiliate
          lessor_objective_ids
          group_id
          supervisor_group_id
          manager_group_id
        ]

        REGEX_PARAMS = %w[
          title
          siret
          siren
        ]

        OBJECTIVES_ACCEPTABLE_PARAMS = %w[
          created_at
          updated_at
          activation_date
          department
          district
          threshold_type
          priority_public
          new_offer
          target_by_typologies
          realized_by_typologies
          present_typologies
          agency_id
        ]

        OBJECTIVES_REGEX_PARAMS = %w[
          district
        ]

        MUTATE_PARAMS = %i[
          title
          siret
          siren
          id_rex
          id_cristal
          api_id
          rpls_id
          affiliate
          lessor_objective_ids
        ]
        def mutate_params
          MUTATE_PARAMS
        end 

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          super
        end

        def objective_handle_params
          acceptable_params *OBJECTIVES_ACCEPTABLE_PARAMS
          regex_params *OBJECTIVES_REGEX_PARAMS
          valid_operators *VALID_OPERATORS
        end
        
        def admin_search
          return render json: {status: "unauthorized", code: 401, message: "user is no superadmin"} unless is_super_admin

          aggregation = Hermes::UserRight.all

          if !params['lessor_params'].blank?
            lessor_query = admin_search_param(
              params: params['lessor_params'], 
              possible_params: [:id, :id_cristal, :siren, :siret],
              partial_regex_params: [:title]
            )
            aggregation = aggregation.where(:lessor_id.in => Hermes::Lessor.where(lessor_query).pluck(:id)) 
          end 

          if !params['user_params'].blank?
            user_query = admin_search_param(
              params: params['user_params'], 
              possible_params: [:id, :email, :auth_roles],
              full_regex_params: [:first_name, :last_name]
            )
            aggregation = aggregation.where(:user_id.in => User.where(user_query).pluck(:id)) 
          end 

          paginate_no_root(
            aggregation,
            each_serializer: Hermes::AdminSearchRightSerializer,
            **@options
          )
        end

        def paginate_objectives(objectives)
          objective_handle_params
          objectives = objectives.where(build_query(Hermes::LessorObjective))
                      .order(order_params)
          Rails.logger.debug "TEST #{objectives.selector}"
          paginate(
            objectives,
            each_serializer: Hermes::LessorObjectiveSerializer
          )
        end

        def all_objectives
          objectives = @instance.lessor_objectives
          paginate_objectives(objectives)
        end

        def active_objectives
          objectives = @instance.lessor_objectives.actives
          paginate_objectives(objectives)
        end

        def switch_manual_mode
          if is_super_admin
            lessor = Hermes::Lessor.find(params[:id])
            if lessor.switch_manual_mode
              render json: {status: "success", code: 200, message: "manual mode switch to #{lessor.manual_mode}"}
            else
              render json: {status: "not found", code: 404, message: 'lessor not found'}
            end 
          else 
            render json: {status: "unauthorized", code: 401, message: "user is not a superadmin"}
          end 
        end 

        def current_operation_names
          operation_names = @instance.current_operation_names
          render :json => operation_names
        end

        def add_user
          if @instance.writable_by? current_user
            user = ::User.find params[:data][:attributes][:user_id]
            if user && user.update(lessor_id: @instance.id) 
              return render json: { data: 'user updated' }
            end
          end
          
          render_json_error(:not_found, :object_not_found) unless @instance
        end

        def remove_user
          if @instance.writable_by? current_user
            user = ::User.find params[:data][:attributes][:user_id]
            if user && user.update(lessor_id: nil) 
              return render json: { data: 'user updated' }
            end
          end
          
          render_json_error(:not_found, :object_not_found) unless @instance
        end

        def rdsl
          return render_json_error(:not_found, :object_not_found) unless @instance

          user_ids = Hermes::UserRight.where(lessor_id: @instance.id, right: 'administrator').pluck(:user_id)
          users = User.where(:id.in => user_ids, auth_roles: 'rdsl')

          paginate(
            users,
            each_serializer: Hermes::UserSerializer,
            **@options
          )
        end
      end
    end
  end
end

==> hermes-6.0.0.11.tar.gz: hermes-6.0.0.11/app/controllers/hermes/api/dmo/lessors_controller.rb <==
# frozen_string_literal: true
require 'json'
module Hermes
  module Api
    module Dmo
      # checker Api::Dmo::HermesController avant d'ajouter des methodes
      class LessorsController < Hermes::Api::Dmo::ApplicationController
        set_instance_for :objectives

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $eq
          $regex
          $all
        ]

        ACCEPTABLE_PARAMS = %w[
          ids
          als_id
          created_at
          updated_at
          title
          siret
          siren
          is_root
          root_id
          parent_id
          id_rex
          id_cristal
          api_id
          rpls_id
          affiliate
          lessor_objective_ids
          group_id
          supervisor_group_id
          manager_group_id
        ]

        REGEX_PARAMS = %w[
          title
          siret
          siren
        ]

        OBJECTIVES_ACCEPTABLE_PARAMS = %w[
          created_at
          updated_at
          activation_date
          department
          district
          threshold_type
          priority_public
          new_offer
          target_by_typologies
          realized_by_typologies
          present_typologies
          agency_id
        ]

        OBJECTIVES_REGEX_PARAMS = %w[
          district
        ]

        MUTATE_PARAMS = %i[
          title
          siret
          siren
          id_rex
          id_cristal
          api_id
          rpls_id
          affiliate
          lessor_objective_ids
        ]
        def mutate_params
          MUTATE_PARAMS
        end 

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          super
        end

        def objective_handle_params
          acceptable_params *OBJECTIVES_ACCEPTABLE_PARAMS
          regex_params *OBJECTIVES_REGEX_PARAMS
          valid_operators *VALID_OPERATORS
        end
        
        def admin_search
          return render json: {status: "unauthorized", code: 401, message: "user is no superadmin"} unless is_super_admin

          aggregation = Hermes::UserRight.all

          if !params['lessor_params'].blank?
            lessor_query = admin_search_param(
              params: params['lessor_params'], 
              possible_params: [:id, :id_cristal, :siren, :siret],
              partial_regex_params: [:title]
            )
            lessor_hint = lessor_query["title"] ? 'title_1' : nil
            aggregation = aggregation.where(:lessor_id.in => Hermes::Lessor.where(lessor_query).hint(lessor_hint).pluck(:id)) 
          end 

          if !params['user_params'].blank?
            user_query = admin_search_param(
              params: params['user_params'], 
              possible_params: [:id, :email, :auth_roles],
              full_regex_params: [:first_name, :last_name]
            )
            user_hint = nil
            user_hint = 'first_name_1' if user_query["first_name"]
            user_hint = 'last_name_1' if user_query["last_name"]
            aggregation = aggregation.where(:user_id.in => User.where(user_query).hint(user_hint).pluck(:id)) 
          end 

          @options[:no_attributes] = true

          paginate(
            aggregation,
            each_serializer: Hermes::AdminSearchRightSerializer,
            **@options
          )
        end

        def paginate_objectives(objectives)
          objective_handle_params
          objectives = objectives.where(build_query(Hermes::LessorObjective))
                      .order(order_params)
          Rails.logger.debug "TEST #{objectives.selector}"
          paginate(
            objectives,
            each_serializer: Hermes::LessorObjectiveSerializer
          )
        end

        def all_objectives
          objectives = @instance.lessor_objectives
          paginate_objectives(objectives)
        end

        def active_objectives
          objectives = @instance.lessor_objectives.actives
          paginate_objectives(objectives)
        end

        def switch_manual_mode
          if is_super_admin
            lessor = Hermes::Lessor.find(params[:id])
            if lessor.switch_manual_mode
              render json: {status: "success", code: 200, message: "manual mode switch to #{lessor.manual_mode}"}
            else
              render json: {status: "not found", code: 404, message: 'lessor not found'}
            end 
          else 
            render json: {status: "unauthorized", code: 401, message: "user is not a superadmin"}
          end 
        end 

        def current_operation_names
          operation_names = @instance.current_operation_names
          render :json => operation_names
        end

        def add_user
          if @instance.writable_by? current_user
            user = ::User.find params[:data][:attributes][:user_id]
            if user && user.update(lessor_id: @instance.id) 
              return render json: { data: 'user updated' }
            end
          end
          
          render_json_error(:not_found, :object_not_found) unless @instance
        end

        def remove_user
          if @instance.writable_by? current_user
            user = ::User.find params[:data][:attributes][:user_id]
            if user && user.update(lessor_id: nil) 
              return render json: { data: 'user updated' }
            end
          end
          
          render_json_error(:not_found, :object_not_found) unless @instance
        end

        def rdsl
          return render_json_error(:not_found, :object_not_found) unless @instance

          user_ids = Hermes::UserRight.where(lessor_id: @instance.id, right: 'administrator').pluck(:user_id)
          users = User.where(:id.in => user_ids, auth_roles: 'rdsl')

          paginate(
            users,
            each_serializer: Hermes::UserSerializer,
            **@options
          )
        end
      end
    end
  end
end
